# Biohit pipettor gui
A modern GUI application for controlling electronic pipettors with advanced 
workflow capabilities. Currently, in use with Biohit but can be used with other pipettors as well.
See more in documentation
[![Documentation](https://img.shields.io/badge/docs-latest-blue.svg)](https://smartlab-network.github.io/open-biohit-gui/)

## Features
1. Interactive GUI with Custom Deck, slot, and labware. Easy definition and visualization.
2. Works on both single and multi pipettor
3. Direct implementation of labware based operations. eg: pick_tips, return_tips, add_medium, remove_medium.
4. Workflow builder to build and run a list of operation 
5. Operation logging. 
6. Ability to save & load Workflow and Deck. 


## Download
[Download Latest Release](https://github.com/smartlab-network/open-biohit-gui/releases/latest)

## Install via PyPI (Recommended for Developers)
Requires **Python 3.10 (32-bit)**  
Download Python: https://www.python.org/downloads/release/python-3100/

### Windows

1. py -3.10 -m venv .venv
2. .venv\Scripts\activate
3. python -m pip install --upgrade pip
4. pip install open-biohit-gui
5. pipettor-gui

### Mac/Linux
1. python3.10 -m venv .venv
2. source .venv/bin/activate
3. python -m pip install --upgrade pip
4. pip install open-biohit-gui
5. pipettor-gui

## Working Tutorial
To see the Biohit Pipettor gui in action, watch the full walkthrough below:
[![Biohit Pipettor GUI Tutorial](https://img.youtube.com/vi/gM6Kxg_iGMc/0.jpg)](https://www.youtube.com/watch?v=gM6Kxg_iGMc)

## Development
Built with:
    - Python 3.10 
    - ttkbootstrap and Tkinter (Modern UI) 
    - matplotlib (Data visualization)

## License
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)


# Biohit Roboline Python Interface
To learn more about the default pipettor in use
[![docs](https://img.shields.io/badge/docs-passing-brightgreen.svg)](https://umg-pharma-lab-automation.pages.gwdg.de/biohit-pipettor-python/)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
